/****************************************************************************
** Meta object code from reading C++ file 'gameview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knetwalk-17.04.3/src/gameview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_GameView_t {
    QByteArrayData data[20];
    char stringdata0[150];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GameView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GameView_t qt_meta_stringdata_GameView = {
    {
QT_MOC_LITERAL(0, 0, 8), // "GameView"
QT_MOC_LITERAL(1, 9, 7), // "newCell"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 5), // "cable"
QT_MOC_LITERAL(4, 24, 4), // "type"
QT_MOC_LITERAL(5, 29, 9), // "setSprite"
QT_MOC_LITERAL(6, 39, 3), // "pos"
QT_MOC_LITERAL(7, 43, 7), // "setSize"
QT_MOC_LITERAL(8, 51, 5), // "width"
QT_MOC_LITERAL(9, 57, 6), // "height"
QT_MOC_LITERAL(10, 64, 15), // "rotationStarted"
QT_MOC_LITERAL(11, 80, 4), // "lock"
QT_MOC_LITERAL(12, 85, 8), // "gameOver"
QT_MOC_LITERAL(13, 94, 3), // "msg"
QT_MOC_LITERAL(14, 98, 17), // "setRotateDuration"
QT_MOC_LITERAL(15, 116, 5), // "solve"
QT_MOC_LITERAL(16, 122, 7), // "clicked"
QT_MOC_LITERAL(17, 130, 5), // "index"
QT_MOC_LITERAL(18, 136, 7), // "rotated"
QT_MOC_LITERAL(19, 144, 5) // "angle"

    },
    "GameView\0newCell\0\0cable\0type\0setSprite\0"
    "pos\0setSize\0width\0height\0rotationStarted\0"
    "lock\0gameOver\0msg\0setRotateDuration\0"
    "solve\0clicked\0index\0rotated\0angle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GameView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   64,    2, 0x06 /* Public */,
       5,    3,   69,    2, 0x06 /* Public */,
       7,    2,   76,    2, 0x06 /* Public */,
      10,    0,   81,    2, 0x06 /* Public */,
      11,    1,   82,    2, 0x06 /* Public */,
      12,    1,   85,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,   88,    2, 0x0a /* Public */,
      15,    0,   89,    2, 0x08 /* Private */,
      16,    1,   90,    2, 0x08 /* Private */,
      18,    2,   93,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariant, QMetaType::QVariant,    3,    4,
    QMetaType::Void, QMetaType::QVariant, QMetaType::QVariant, QMetaType::QVariant,    6,    3,    4,
    QMetaType::Void, QMetaType::QVariant, QMetaType::QVariant,    8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,   13,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   17,   19,

       0        // eod
};

void GameView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameView *_t = static_cast<GameView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newCell((*reinterpret_cast< QVariant(*)>(_a[1])),(*reinterpret_cast< QVariant(*)>(_a[2]))); break;
        case 1: _t->setSprite((*reinterpret_cast< QVariant(*)>(_a[1])),(*reinterpret_cast< QVariant(*)>(_a[2])),(*reinterpret_cast< QVariant(*)>(_a[3]))); break;
        case 2: _t->setSize((*reinterpret_cast< QVariant(*)>(_a[1])),(*reinterpret_cast< QVariant(*)>(_a[2]))); break;
        case 3: _t->rotationStarted(); break;
        case 4: _t->lock((*reinterpret_cast< QVariant(*)>(_a[1]))); break;
        case 5: _t->gameOver((*reinterpret_cast< QVariant(*)>(_a[1]))); break;
        case 6: _t->setRotateDuration(); break;
        case 7: _t->solve(); break;
        case 8: _t->clicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->rotated((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (GameView::*_t)(QVariant , QVariant );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::newCell)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(QVariant , QVariant , QVariant );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::setSprite)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(QVariant , QVariant );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::setSize)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GameView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::rotationStarted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(QVariant );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::lock)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(QVariant );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::gameOver)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject GameView::staticMetaObject = {
    { &KgDeclarativeView::staticMetaObject, qt_meta_stringdata_GameView.data,
      qt_meta_data_GameView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *GameView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_GameView.stringdata0))
        return static_cast<void*>(const_cast< GameView*>(this));
    return KgDeclarativeView::qt_metacast(_clname);
}

int GameView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KgDeclarativeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void GameView::newCell(QVariant _t1, QVariant _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void GameView::setSprite(QVariant _t1, QVariant _t2, QVariant _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void GameView::setSize(QVariant _t1, QVariant _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void GameView::rotationStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void GameView::lock(QVariant _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void GameView::gameOver(QVariant _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_END_MOC_NAMESPACE
